@@ -1,8 +1,9 @@
-# Filesys::POSIX           Copyright (c) 2011 cPanel, Inc.  All rights reserved.
-# copyright@cpanel.net                                        http://cpanel.net/
-# 
-# Written by Erin Schönhals <erin@cpanel.net>.  Released under the terms of the
-# Perl Artistic License.
+# Copyright (c) 2012, cPanel, Inc.
+# All rights reserved.
+# http://cpanel.net/
+#
+# This is free software; you can redistribute it and/or modify it under the same
+# terms as Perl itself.  See the LICENSE file for further details.
 
 package Filesys::POSIX::Userland::Tar;
 
@@ -109,7 +110,7 @@ specified, the data is passed unmodified to L<Filesys::POSIX::Userland::Find>.
 In this way, for instance, the behavior of following symlinks can be specified.
 
 In addition to options supported by L<Filesys::POSIX::Userland::Find>, the
-following options are recognized uniquely by C<$FS-E<gt>tar()>:
+following options are recognized uniquely by C<$fs-E<gt>tar()>:
 
 =over
 
